play_tetris: Tetris Game

Description Usage Arguments Examples

View source: R/play_tetris.R

Description

This function is an implementation of Tetris based on X window system.

Usage

1
2
play_tetris(nhint = 5, speed = 1, bg = "#a9e0f9", ...,
  color = setNames(hue_pal()(7), c("I", "J", "L", "O", "S", "T", "Z")))

Arguments

nhint

the number of hint squares on the right

speed

the level of speed at which block is falling

bg

the initial background color. Default "skyblue".

...

optional arguments to x11, except for width and height

color

a named character vector representing the colors of seven tetrominoes

Examples

1
2
3
4
## Not run: 
play_tetris()

## End(Not run)

darrennn/gamer documentation built on Nov. 8, 2019, 1:37 p.m.