Description Usage Arguments Examples
This function is an implementation of Tetris based on X window system.
1 2 | play_tetris(nhint = 5, speed = 1, bg = "#a9e0f9", ...,
color = setNames(hue_pal()(7), c("I", "J", "L", "O", "S", "T", "Z")))
|
nhint |
the number of hint squares on the right |
speed |
the level of speed at which block is falling |
bg |
the initial background color. Default "skyblue". |
... |
optional arguments to |
color |
a named character vector representing the colors of seven tetrominoes |
1 2 3 4 | ## Not run:
play_tetris()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.